#ifndef CHROMEOS_CAMERA_LIB_MEDIAPIPE_SHIM_FRAMEWORK_FORMATS_ANY_H_
#define CHROMEOS_CAMERA_LIB_MEDIAPIPE_SHIM_FRAMEWORK_FORMATS_ANY_H_

namespace mediapipe_shim {

//
// Abstract base class for passing a custom RAII packet type as
// std::unique_ptr<Any> in the shim library. The user is responsible for type
// consistency and thread safety of the data.
//
// Example:
//
//    class MyPacketType : public mediapipe_shim::Any {
//      ...
//    };
//
//    Packet packet = AdoptAsUniquePtr<Any>(new MyPacketType(...));
//    MyPacketType* data = GetFromUniquePtr<Any>(packet)->As<MyPacketType>();
//
class Any {
 public:
  virtual ~Any() = default;

  template <typename T>
  T* As() {
    return static_cast<T*>(this);
  }
};

}  // namespace mediapipe_shim

#endif  // CHROMEOS_CAMERA_LIB_MEDIAPIPE_SHIM_FRAMEWORK_FORMATS_ANY_H_
